@@ -9,18 +9,17 @@ from django.utils.deprecation import MiddlewareMixin
 from . import utils as maintenance
 from .conf import settings
 
-urls.handler503 = 'maintenancemode.views.temporary_unavailable'
-urls.__all__.append('handler503')
+urls.handler503 = "maintenancemode.views.temporary_unavailable"
+urls.__all__.append("handler503")
 
 IGNORE_URLS = tuple([re.compile(u) for u in settings.MAINTENANCE_IGNORE_URLS])
 
 
 class MaintenanceModeMiddleware(MiddlewareMixin):
-
     def process_request(self, request):
         # Allow access if middleware is not activated
-        allow_staff = getattr(settings, 'MAINTENANCE_ALLOW_STAFF', True)
-        allow_superuser = getattr(settings, 'MAINTENANCE_ALLOW_SUPERUSER', True)
+        allow_staff = getattr(settings, "MAINTENANCE_ALLOW_STAFF", True)
+        allow_superuser = getattr(settings, "MAINTENANCE_ALLOW_SUPERUSER", True)
 
         if not (settings.MAINTENANCE_MODE or maintenance.status()):
             return None
@@ -29,21 +28,21 @@ class MaintenanceModeMiddleware(MiddlewareMixin):
 
         # Preferentially check HTTP_X_FORWARDED_FOR b/c a proxy
         # server might have obscured REMOTE_ADDR
-        for ip in request.META.get('HTTP_X_FORWARDED_FOR', '').split(','):
+        for ip in request.META.get("HTTP_X_FORWARDED_FOR", "").split(","):
             if ip.strip() in INTERNAL_IPS:
                 return None
 
         # Allow access if remote ip is in INTERNAL_IPS
-        if request.META.get('REMOTE_ADDR') in INTERNAL_IPS:
+        if request.META.get("REMOTE_ADDR") in INTERNAL_IPS:
             return None
 
         # Allow access if the user doing the request is logged in and a
         # staff member.
-        if hasattr(request, 'user'):
-            if request.user.is_staff and allow_staff:
+        if hasattr(request, "user"):
+            if allow_staff and request.user.is_staff:
                 return None
 
-            if request.user.is_superuser and allow_superuser:
+            if allow_superuser and request.user.is_superuser:
                 return None
 
         # Check if a path is explicitly excluded from maintenance mode
@@ -54,6 +53,6 @@ class MaintenanceModeMiddleware(MiddlewareMixin):
         # Otherwise show the user the 503 page
         resolver = get_resolver()
 
-        callback, param_dict = resolver.resolve_error_handler('503')
+        callback, param_dict = resolver.resolve_error_handler("503")
 
         return callback(request, **param_dict)
